registerUsage method
Paid container software products sold through AWS Marketplace must integrate with the AWS Marketplace Metering Service and call the RegisterUsage operation for software entitlement and metering. Free and BYOL products for Amazon ECS or Amazon EKS aren't required to call RegisterUsage, but you may choose to do so if you would like to receive usage data in your seller reports. The sections below explain the behavior of RegisterUsage. RegisterUsage performs two primary functions: metering and entitlement.
- Entitlement: RegisterUsage allows you to verify that the customer running your paid software is subscribed to your product on AWS Marketplace, enabling you to guard against unauthorized use. Your container image that integrates with RegisterUsage is only required to guard against unauthorized use at container startup, as such a CustomerNotSubscribedException/PlatformNotSupportedException will only be thrown on the initial call to RegisterUsage. Subsequent calls from the same Amazon ECS task instance (e.g. task-id) or Amazon EKS pod will not throw a CustomerNotSubscribedException, even if the customer unsubscribes while the Amazon ECS task or Amazon EKS pod is still running.
- Metering: RegisterUsage meters software use per ECS task, per hour, or per pod for Amazon EKS with usage prorated to the second. A minimum of 1 minute of usage applies to tasks that are short lived. For example, if a customer has a 10 node Amazon ECS or Amazon EKS cluster and a service configured as a Daemon Set, then Amazon ECS or Amazon EKS will launch a task on all 10 cluster nodes and the customer will be charged: (10 * hourly_rate). Metering for software use is automatically handled by the AWS Marketplace Metering Control Plane -- your software is not required to perform any metering specific actions, other than call RegisterUsage once for metering of software use to commence. The AWS Marketplace Metering Control Plane will also continue to bill customers for running ECS tasks and Amazon EKS pods, regardless of the customers subscription state, removing the need for your software to perform entitlement checks at runtime.
May throw InvalidProductCodeException. May throw InvalidRegionException. May throw InvalidPublicKeyVersionException. May throw PlatformNotSupportedException. May throw CustomerNotEntitledException. May throw ThrottlingException. May throw InternalServiceErrorException. May throw DisabledApiException.
Parameter productCode :
Product code is used to uniquely identify a product in AWS Marketplace.
The product code should be the same as the one used during the publishing
of a new product.
Parameter publicKeyVersion :
Public Key Version provided by AWS Marketplace
Parameter nonce :
(Optional) To scope down the registration to a specific running software
instance and guard against replay attacks.
Implementation
Future<RegisterUsageResult> registerUsage({
required String productCode,
required int publicKeyVersion,
String? nonce,
}) async {
ArgumentError.checkNotNull(productCode, 'productCode');
_s.validateStringLength(
'productCode',
productCode,
1,
255,
isRequired: true,
);
ArgumentError.checkNotNull(publicKeyVersion, 'publicKeyVersion');
_s.validateNumRange(
'publicKeyVersion',
publicKeyVersion,
1,
1152921504606846976,
isRequired: true,
);
_s.validateStringLength(
'nonce',
nonce,
0,
255,
);
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSMPMeteringService.RegisterUsage'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
'ProductCode': productCode,
'PublicKeyVersion': publicKeyVersion,
if (nonce != null) 'Nonce': nonce,
},
);
return RegisterUsageResult.fromJson(jsonResponse.body);
}